'use strict';

var _expect = require('expect');

var _expect2 = _interopRequireDefault(_expect);

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _reactDom = require('react-dom');

var _server = require('react-dom/server');

var _Media = require('../Media');

var _Media2 = _interopRequireDefault(_Media);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

describe('A <Media>', function () {
  var node = void 0;
  beforeEach(function () {
    node = document.createElement('div');
  });

  describe('with a query that matches', function () {
    var query = '(max-width: ' + window.innerWidth + 'px)';

    describe('and a children element', function () {
      it('renders its child', function () {
        var element = _react2.default.createElement(
          _Media2.default,
          { query: query },
          _react2.default.createElement(
            'div',
            null,
            'hello'
          )
        );

        (0, _reactDom.render)(element, node, function () {
          (0, _expect2.default)(node.firstChild.innerHTML).toMatch(/hello/);
        });
      });
    });

    describe('and a children function', function () {
      it('renders its child', function () {
        var element = _react2.default.createElement(
          _Media2.default,
          { query: query },
          function (matches) {
            return matches ? _react2.default.createElement(
              'div',
              null,
              'hello'
            ) : _react2.default.createElement(
              'div',
              null,
              'goodbye'
            );
          }
        );

        (0, _reactDom.render)(element, node, function () {
          (0, _expect2.default)(node.firstChild.innerHTML).toMatch(/hello/);
        });
      });
    });

    describe('and a render function', function () {
      it('renders its child', function () {
        var element = _react2.default.createElement(_Media2.default, { query: query, render: function render() {
            return _react2.default.createElement(
              'div',
              null,
              'hello'
            );
          } });

        (0, _reactDom.render)(element, node, function () {
          (0, _expect2.default)(node.firstChild.innerHTML).toMatch(/hello/);
        });
      });
    });
  });

  describe('with a query that does not match', function () {
    var query = '(min-width: ' + (window.innerWidth + 1) + 'px)';

    describe('and a children element', function () {
      it('renders its child', function () {
        var element = _react2.default.createElement(
          _Media2.default,
          { query: query },
          _react2.default.createElement(
            'div',
            null,
            'hello'
          )
        );

        (0, _reactDom.render)(element, node, function () {
          (0, _expect2.default)(node.firstChild.innerHTML).toNotMatch(/hello/);
        });
      });
    });

    describe('and a children function', function () {
      it('renders its child', function () {
        var element = _react2.default.createElement(
          _Media2.default,
          { query: query },
          function (matches) {
            return matches ? _react2.default.createElement(
              'div',
              null,
              'hello'
            ) : _react2.default.createElement(
              'div',
              null,
              'goodbye'
            );
          }
        );

        (0, _reactDom.render)(element, node, function () {
          (0, _expect2.default)(node.firstChild.innerHTML).toMatch(/goodbye/);
        });
      });
    });

    describe('and a render function', function () {
      it('does not render', function () {
        var element = _react2.default.createElement(_Media2.default, { query: query, render: function render() {
            return _react2.default.createElement(
              'div',
              null,
              'hello'
            );
          } });

        (0, _reactDom.render)(element, node, function () {
          (0, _expect2.default)(node.firstChild.innerHTML).toNotMatch(/hello/);
        });
      });

      it('does not call the render function', function () {
        var renderWasCalled = false;
        var element = _react2.default.createElement(_Media2.default, { query: query, render: function render() {
            renderWasCalled = true;
            return _react2.default.createElement('div', null);
          } });

        (0, _reactDom.render)(element, node, function () {
          (0, _expect2.default)(renderWasCalled).toBe(false);
        });
      });
    });
  });

  describe('rendered on the server', function () {
    it('renders its child', function () {
      var markup = (0, _server.renderToStaticMarkup)(_react2.default.createElement(
        _Media2.default,
        { query: '(min-width: 200px)' },
        _react2.default.createElement(
          'div',
          null,
          'hello'
        )
      ));

      (0, _expect2.default)(markup).toMatch(/hello/);
    });
  });
});